@@ -1,36 +1,44 @@
-import jax
-from jax import lax
-from jax import random
-import jax.numpy as jnp
-
-import flax
 from flax import nn
 
 
 class FeedForward(nn.Module):
-  """ """
+  """Simple FeedForward module
+
+  x -> Dense(x, latent_dim) -> GeLU -> Dense(x, original_dim)
+  """
   def apply(self, x, latent_dim):
     dim = x.shape[-1]
-    x = nn.Dense(x, latent_dim, name='fc1')
+    x = nn.Dense(x, latent_dim)
     x = nn.gelu(x)
-    x = nn.Dense(x, dim, name='fc2')
+    x = nn.Dense(x, dim)
     return x
 
 
 class Residual(nn.Module):
-  """ """
+  """Simple residual function
+
+  x -> fn(x) + x"""
   def apply(self, x, residual_fn):
     return residual_fn(x) + x
 
 
 class PreNorm(nn.Module):
-  """ """
+  """Apply function to a normalized modulue
+  """
   def apply(self, x, norm, fn):
     return fn(norm(x))
-      
+
 
 class Transformer(nn.Module):
-  """ """
+  """A simple implementation of a Transformer
+
+  :param x: Input tensor.
+  :param depth: Number of layers of Residual-normalized attention layers.
+  :param num_heads: Number of attention heads
+  :param feed_forward_dim: FC dimension
+
+  :return: Transformer output embedding
+  """
   def apply(self, x, depth, num_heads, feed_forward_dim_1):
     attention = nn.SelfAttention.partial(num_heads=num_heads)
     norm = nn.LayerNorm
@@ -44,4 +52,4 @@ class Transformer(nn.Module):
     for _ in range(depth):
       x = residual_forward(residual_attention(x))
 
-    return x
\ No newline at end of file
+    return x
